==> paco-cloud-3.5.0.tar.gz: paco-cloud-3.5.0/README.md <==
# Paco: Prescribed automation for cloud orchestration

 [![PyPi version](https://img.shields.io/pypi/v/paco-cloud.svg)](https://pypi.python.org/pypi/paco-cloud/) [![](https://img.shields.io/badge/python-3.6+-blue.svg)](https://www.python.org/downloads/) ![t](https://img.shields.io/badge/status-stable-green.svg) [![](https://img.shields.io/github/license/waterbear-cloud/paco.svg)](https://github.com/waterbear-cloud/paco/blob/master/LICENSE.md)


Paco is a cloud orchestration tool for AWS. It enables you to automate the creation and management of your cloud resources. It is a declarative YAML driven tool, that does not require you to write an code. More information is available on the [Paco web site](https://paco.waterbear.cloud).

## Use Paco

Paco can be pip installed from the [paco-cloud](https://pypi.org/project/paco-cloud) package on PyPI.

    pip install paco-cloud

For more information see the [Paco install](http://paco.waterbear.cloud/en/latest/install.html) instructions.
Then see [Getting Started with Paco](http://paco.waterbear.cloud/en/latest/started.html) to learn how to
create a Paco project and connect it to your AWS account.


## Get Involved

 - Give us a Git Star and share on social media with #PacoCloud. Community discussion happens on
   [/r/paco_cloud](https://www.reddit.com/r/paco_cloud/).

 - [Feature request and bug reports](https://github.com/waterbear-cloud/paco/issues) are here on GitHub.

 - To develop Paco, git clone this project as well as [paco.models](https://github.com/waterbear-cloud/paco.models).

 - Send us pull requests. We develop on the master branch to encourage integrating early and often.
   We try to also keep master production-ready but it may not always be the case.

## Authors

Paco is created by Kevin Lindsay and Kevin Teague for [Waterbear Cloud](https://waterbear.cloud).

==> paco-cloud-9.3.22.tar.gz: paco-cloud-9.3.22/README.md <==
# Paco: Prescribed automation for cloud orchestration

 [![PyPi version](https://img.shields.io/pypi/v/paco-cloud.svg)](https://pypi.python.org/pypi/paco-cloud/) [![](https://img.shields.io/badge/python-3.6+-blue.svg)](https://www.python.org/downloads/) ![t](https://img.shields.io/badge/status-stable-green.svg) [![](https://img.shields.io/github/license/waterbear-cloud/paco.svg)](https://github.com/waterbear-cloud/paco/blob/master/LICENSE.md)


Paco is a cloud orchestration tool for AWS. It enables you to automate the creation and management of your cloud resources
with declarative YAML. For more see the [paco-cloud.io web site](https://www.paco-cloud.io).

## Use Paco

Paco can be pip installed from the [paco-cloud](https://pypi.org/project/paco-cloud) package on PyPI.

    pip install paco-cloud

For more information see the [Paco install](https://www.paco-cloud.io/en/latest/install.html) instructions.
Then see [Getting Started with Paco](https://www.paco-cloud.io/en/latest/started.html) to learn how to
create a Paco project and connect it to your AWS account.


## Get Involved

 - Give us a Git Star and share on social media with #PacoCloud. Community discussion happens on
   [/r/paco_cloud](https://www.reddit.com/r/paco_cloud/).

- Chat with us on [Gitter at paco-cloud](https://gitter.im/paco-cloud/community).

 - Submit [feature request and bug reports](https://github.com/waterbear-cloud/paco/issues) on GitHub.

 - To develop Paco, git clone this project as well as [paco.models](https://github.com/waterbear-cloud/paco.models).

## Authors

Paco is created by Kevin Lindsay and Kevin Teague for [Waterbear Cloud](https://waterbear.cloud).
